==> WinBinder-0.30.101.tgz: Code/make_release/make.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG1001")) define("IDD_DLG1001", 1001);
if(!defined("IDC_RESULT")) define("IDC_RESULT", 1002);
if(!defined("IDC_VERSION")) define("IDC_VERSION", 1007);
if(!defined("IDC_TYPE")) define("IDC_TYPE", 1009);
if(!defined("IDC_VERBOSE")) define("IDC_VERBOSE", 1010);
if(!defined("IDC_STATIC1008")) define("IDC_STATIC1008", 1008);
if(!defined("IDC_BUILD")) define("IDC_BUILD", 1011);
if(!defined("IDC_NOTES")) define("IDC_NOTES", 1012);
if(!defined("IDC_STATIC1013")) define("IDC_STATIC1013", 1013);

// Create window

$mainwin = wb_create_window(NULL, PopupWindow, "Make releases", WBC_CENTER, WBC_CENTER, 684, 408, 0, 0);

// Insert controls

wb_create_control($mainwin, EditBox, "", 271, 55, 403, 300, IDC_RESULT, WBC_VISIBLE | WBC_ENABLED | WBC_MULTILINE);
wb_create_control($mainwin, EditBox, "Version", 49, 29, 95, 21, IDC_VERSION, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Version:", 4, 32, 40, 16, IDC_STATIC1008, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, ComboBox, "", 271, 29, 149, 98, IDC_TYPE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Verbose", 433, 29, 61, 21, IDC_VERBOSE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Build", 501, 29, 46, 21, IDC_BUILD, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "", 4, 55, 261, 300, IDC_NOTES, WBC_VISIBLE | WBC_ENABLED | WBC_MULTILINE);
wb_create_control($mainwin, Label, "Release type:", 167, 32, 101, 16, IDC_STATIC1013, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);

// End controls

?>

==> WinBinder-0.31.104.tgz: Code/make_release/make.rc.php <==
<?php

// Control identifiers

if(!defined("IDD_DLG1001")) define("IDD_DLG1001", 1001);
if(!defined("IDC_RESULT")) define("IDC_RESULT", 1002);
if(!defined("IDC_VERSION")) define("IDC_VERSION", 1007);
if(!defined("IDC_TYPE")) define("IDC_TYPE", 1009);
if(!defined("IDC_VERBOSE")) define("IDC_VERBOSE", 1010);
if(!defined("IDC_STATIC1008")) define("IDC_STATIC1008", 1008);
if(!defined("IDC_BUILD")) define("IDC_BUILD", 1011);
if(!defined("IDC_NOTES")) define("IDC_NOTES", 1012);
if(!defined("IDC_STATIC1013")) define("IDC_STATIC1013", 1013);

// Create window

$mainwin = wb_create_window(NULL, PopupWindow, "Make releases", WBC_CENTER, WBC_CENTER, 684, 408, 0, 0);

// Insert controls

wb_create_control($mainwin, EditBox, "", 271, 55, 403, 300, IDC_RESULT, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, EditBox, "Version", 49, 29, 95, 21, IDC_VERSION, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, Label, "Version:", 4, 32, 40, 16, IDC_STATIC1008, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);
wb_create_control($mainwin, ComboBox, "", 271, 29, 149, 98, IDC_TYPE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Verbose", 433, 29, 61, 21, IDC_VERBOSE, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, CheckBox, "Build", 501, 29, 46, 21, IDC_BUILD, WBC_VISIBLE | WBC_ENABLED);
wb_create_control($mainwin, EditBox, "", 4, 55, 261, 300, IDC_NOTES, WBC_VISIBLE | WBC_ENABLED | WBC_LINES);
wb_create_control($mainwin, Label, "Release type:", 167, 32, 101, 16, IDC_STATIC1013, WBC_VISIBLE | WBC_ENABLED | WBC_RIGHT);

// End controls

?>
